@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: MIDI pitches for guitar chord voicings
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0300';
 
 use strict;
 use warnings;
@@ -12,7 +12,7 @@ use File::ShareDir qw(dist_dir);
 use List::Util qw(any);
 use Moo;
 use Music::Note;
-use Text::CSV_XS;
+use Text::CSV_XS ();
 
 
 has chords => (
@@ -60,10 +60,18 @@ sub transform {
     my ($self, $target, $chord_name, $variation) = @_;
     $target = Music::Note->new($target, 'ISO')->format('midinum');
     $chord_name //= '';
-    $variation //= 0;
-    my $pitches = $self->chords->{ 'C' . $chord_name }[$variation];
-    my $diff = $target - _lowest_c($pitches);
-    my @notes = map { $_ + $diff } @$pitches;
+    my @notes;
+    if (defined $variation) {
+      my $pitches = $self->chords->{ 'C' . $chord_name }[$variation];
+      my $diff = $target - _lowest_c($pitches);
+      @notes = map { $_ + $diff } @$pitches;
+    }
+    else {
+        for my $pitches ($self->chords->{ 'C' . $chord_name }->@*) {
+            my $diff = $target - _lowest_c($pitches);
+            push @notes, [ map { $_ + $diff } @$pitches ];
+        }
+    }
     return \@notes;
 }
 
@@ -114,7 +122,7 @@ MIDI::Chord::Guitar - MIDI pitches for guitar chord voicings
 
 =head1 VERSION
 
-version 0.0202
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -122,14 +130,18 @@ version 0.0202
 
   my $mcg = MIDI::Chord::Guitar->new;
 
+  my $chords = $mcg->transform('D3', 'dim7');
+  # [ [41, 47, 50, 56], [50, 56, 59, 65, 68] ]
+
+  my $chord = $mcg->transform('D3', 'dim7', 0);
+  # [41, 47, 50, 56]
+
   my $voicings = $mcg->voicings('dim7');
-  # [ [51,57,60,66], [48,54,57,63,66] ]
+  # [ [51, 57, 60, 66], [48, 54, 57, 63, 66] ]
 
   $voicings = $mcg->voicings('dim7', 'ISO');
   # [ [D#3 A3 C4 F#4], [C3 F#3 A3 D#4 F#4] ]
 
-  my $chord = $mcg->transform('D3', 'dim7', 0);
-
   # MIDI:
   #$score->n('wn', @$chord);
 
@@ -194,14 +206,17 @@ Return the guitar chord data filename location.
 =head2 transform
 
   $chord = $mcg->transform($target, $chord_name, $variation);
+  $chords = $mcg->transform($target, $chord_name);
 
-Find the chord given the B<target>, B<chord_name> and B<variation>.
+Find the chord given the B<target>, B<chord_name> and an optional
+B<variation>.
 
 The B<target> must be in the format of an C<ISO> note (e.g. on the
 guitar, a C note is represented by C<C3>, C<C4>, C<C5>, etc).
 
-If no B<chord_name> is given, C<major> is used.  If no B<variation> is
-given, C<0> is used.
+If no B<chord_name> is given, C<major> is used.
+
+If no B<variation> is given, all transformed voicings are returned.
 
 =head2 voicings
 
@@ -231,6 +246,9 @@ B<as_file> method:
   C7,60,67,70,76,,
   ...
 
+Check out the link in the L</"SEE ALSO"> section for the chord shapes
+used to create this.
+
 =head1 SEE ALSO
 
 The F<t/01-methods.t> and F<eg/autumn_leaves> files in this distribution
@@ -245,6 +263,8 @@ L<Music::Note>
 
 L<Text::CSV_XS>
 
+L<https://www.guitartricks.com/chords/C-chord> shapes
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
